### Name: iterators
### Title: Vertex and edge sequences
### Aliases: igraph.es.adj igraph.es.all igraph.es.end igraph.es.from
###   igraph.es.fromorder igraph.es.get igraph.es.next igraph.es.reset
###   $.igraphesseq igraph.es.to $.igraphesvector igraph.es.vector
###   igraph.vs.adj igraph.vs.all igraph.vs.end igraph.vs.get
###   igraph.vs.next igraph.vs.reset $.igraphvsseq $.igraphvsvector
###   igraph.vs.vector as.vector.igraphvsseq as.vector.igraphvsvector
###   as.vector.igraphesseq as.vector.igraphesvector as.vector
### Keywords: graphs

### ** Examples

# mean degree of vertices in the largest cluster in a random graph
g <- erdos.renyi.game(100, 2/100)
c <- clusters(g)
vsl <- igraph.vs.vector(g, which(which.max(c$csize)-1==c$membership)-1)
mean(degree(g, vsl))

# set the color of these vertices to red, others greens
g <- add.vertex.attribute(g, "color", type="string")
v.a(g, "color") <- "green"
v.a(g, "color", vsl) <- "red"
## Not run: plot(g, vertex.size=3, labels=NA, vertex.color="a:color")

# the longest geodesic within the largest cluster
vsl <- igraph.vs.reset(g, vsl) # just to be sure
long <- numeric()
while (!vsl$end) {
  paths <- get.shortest.paths(g, vsl$v)
  paths <- paths[ as.vector(vsl)+1  ]
  fl <- paths[[ which.max(sapply(paths, length)) ]]
  if (length(fl) > length(long)) {
    long <- fl
  }
  vsl <- vsl$step
}



